function varargout = AddSubplotWindow(varargin)
% ADDSUBPLOTWINDOW M-file for AddSubplotWindow.fig
%      ADDSUBPLOTWINDOW, by itself, creates a new ADDSUBPLOTWINDOW or raises the existing
%      singleton*.
%
%      H = ADDSUBPLOTWINDOW returns the handle to a new ADDSUBPLOTWINDOW or the handle to
%      the existing singleton*.
%
%      ADDSUBPLOTWINDOW('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in ADDSUBPLOTWINDOW.M with the given input arguments.
%
%      ADDSUBPLOTWINDOW('Property','Value',...) creates a new ADDSUBPLOTWINDOW or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before AddSubplotWindow_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to AddSubplotWindow_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES
 
% Copyright 2002-2003 The MathWorks, Inc.
 
% Edit the above text to modify the response to help AddSubplotWindow
 
% Last Modified by GUIDE v2.5 10-Aug-2006 15:33:13
 
% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @AddSubplotWindow_OpeningFcn, ...
                   'gui_OutputFcn',  @AddSubplotWindow_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end
 
if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT
 
 
% --- Executes just before AddSubplotWindow is made visible.
function AddSubplotWindow_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to AddSubplotWindow (see VARARGIN)
 
% Choose default command line output for AddSubplotWindow
handles.output = hObject;
 
handles.SubplotProperties=varargin{2};
handles.NrSubplots=varargin{4};
handles.ActiveFigure=varargin{6};
handles.Position=varargin{8};
% handles.NrSubplots=varargin{2};
% handles.Position=varargin{4};
handles.output='';
handles.second_output=[-999 -999 -999 -999];

PutInCentre(hObject);

set(handles.EditPosition1,'String',num2str(handles.Position(1)));
set(handles.EditPosition2,'String',num2str(handles.Position(2)));
set(handles.EditPosition3,'String',num2str(handles.Position(3)));
set(handles.EditPosition4,'String',num2str(handles.Position(4)));
 
str=['Subplot ' num2str(handles.NrSubplots+1)];
set(handles.EditSubplotName,'String',str);

set(handles.ToggleTextBox,'Value',0);
set(handles.ToggleTextBox,'Visible','off');
 
% Update handles structure
guidata(hObject, handles);
 
% UIWAIT makes AddSubplotWindow wait for user response (see UIRESUME)
uiwait(handles.figure1);
 
 
% --- Outputs from this function are returned to the command line.
function varargout = AddSubplotWindow_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
 
% Get default command line output from handles structure

varargout{1} = handles.output;
varargout{2} = handles.second_output;
 
close(handles.figure1);
 
 
function EditPosition1_Callback(hObject, eventdata, handles)
% hObject    handle to EditPosition1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
 
% Hints: get(hObject,'String') returns contents of EditPosition1 as text
%        str2double(get(hObject,'String')) returns contents of EditPosition1 as a double
 
 
% --- Executes during object creation, after setting all properties.
function EditPosition1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to EditPosition1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
 
% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end
 
 
 
function EditPosition2_Callback(hObject, eventdata, handles)
% hObject    handle to EditPosition2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
 
% Hints: get(hObject,'String') returns contents of EditPosition2 as text
%        str2double(get(hObject,'String')) returns contents of EditPosition2 as a double


% --- Executes during object creation, after setting all properties.
function EditPosition2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to EditPosition2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
 
% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end
 
 
function EditPosition3_Callback(hObject, eventdata, handles)
% hObject    handle to EditPosition3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
 
% Hints: get(hObject,'String') returns contents of EditPosition3 as text
%        str2double(get(hObject,'String')) returns contents of EditPosition3 as a double
 
 
% --- Executes during object creation, after setting all properties.
function EditPosition3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to EditPosition3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
 
% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end
 
 
 
function EditPosition4_Callback(hObject, eventdata, handles)
% hObject    handle to EditPosition4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
 
% Hints: get(hObject,'String') returns contents of EditPosition4 as text
%        str2double(get(hObject,'String')) returns contents of EditPosition4 as a double
 
 
% --- Executes during object creation, after setting all properties.
function EditPosition4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to EditPosition4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
 
% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end
 
 
 
function EditSubplotName_Callback(hObject, eventdata, handles)
% hObject    handle to EditSubplotName (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
 
% Hints: get(hObject,'String') returns contents of EditSubplotName as text
%        str2double(get(hObject,'String')) returns contents of EditSubplotName as a double
 
 
% --- Executes during object creation, after setting all properties.
function EditSubplotName_CreateFcn(hObject, eventdata, handles)
% hObject    handle to EditSubplotName (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
 
% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end
 
 
% --- Executes on button press in PushOK.
function PushOK_Callback(hObject, eventdata, handles)
% hObject    handle to PushOK (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
 
Position(1)=str2num(get(handles.EditPosition1,'String'));
Position(2)=str2num(get(handles.EditPosition2,'String'));
Position(3)=str2num(get(handles.EditPosition3,'String'));
Position(4)=str2num(get(handles.EditPosition4,'String'));
Name=get(handles.EditSubplotName,'String');

handles.output=Name;
handles.second_output=Position;
 
guidata(hObject, handles);
 
uiresume;
 
% --- Executes on button press in PushCancel.
function PushCancel_Callback(hObject, eventdata, handles)
% hObject    handle to PushCancel (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
 
uiresume;
 


% --- Executes on button press in ToggleTextBox.
function ToggleTextBox_Callback(hObject, eventdata, handles)
% hObject    handle to ToggleTextBox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of ToggleTextBox


